@@ -27,7 +27,7 @@ project_format_version: str = "7.0"
 # minimal project version for handling observations from images
 IMAGES_OBS_PROJECT_MIN_VERSION: tuple = (8, 6)
 
-IMAGE_EXTENSIONS: tuple = ("*.jpg", "*.png", "*.jpeg")
+IMAGE_EXTENSIONS: tuple = ("*.jpg", "*.png", "*.jpeg", "*.tiff", "*.tif", "*.webp", "*.bmp")
 
 CHECK_NEW_VERSION_DELAY: int = 15 * 24 * 60 * 60
 
@@ -37,9 +37,13 @@ MAX_UNDO_QUEUE: int = 25
 
 NA: str = "NA"
 
-CTRL_KEY = "Ctrl"
+REALTIME_PLOT_CURSOR_COLOR = "red"
 
-SPECTRO_TIMER = 500
+DYNAMIC_TIME_CUTOFF_DEFAULT = 300
+
+CTRL_KEY: str = "Ctrl"
+
+SPECTRO_TIMER: int = 500
 
 function_keys = {
     16777264: "F1",
@@ -72,6 +76,7 @@ BEHAVIORS_CODING_MAP = "behaviors_coding_map"
 SUBJECTS = "subjects_conf"
 ETHOGRAM = "behaviors_conf"
 BEHAVIORAL_CATEGORIES = "behavioral_categories"
+BEHAVIORAL_CATEGORIES_CONF = "behavioral_categories_config"
 CONVERTERS = "converters"
 
 OFFSET = "offset"
@@ -138,6 +143,7 @@ NO_FOCAL_SUBJECT = "No focal subject"
 
 TYPE = "type"
 FILE = "file"
+COLOR = "color"
 DIRECTORIES_LIST = "directories_list"
 
 SAVE_DATASET = 32
@@ -179,8 +185,10 @@ FILE_PATH = "file_path"
 
 IMAGE_INDEX = "image index"
 IMAGE_PATH = "image path"
+FRAME_INDEX = "frame index"
 
 ZOOM_LEVEL = "zoom level"
+ROTATION_ANGLE = "rotation angle"
 DISPLAY_MEDIA_SUBTITLES = "display subtitles"
 OVERLAY = "video overlay"
 
@@ -207,9 +215,10 @@ ETHOGRAM_TABLE_COLUMNS: dict = {
     1: "code",
     2: "type",
     3: "description",
-    4: "category",
-    5: "modifiers",
-    6: "excluded",
+    4: "color",
+    5: "category",
+    6: "modifiers",
+    7: "excluded",
 }
 
 # fields in ethogram table from project window
@@ -218,10 +227,11 @@ behavioursFields: dict = {
     "key": 1,
     "code": 2,
     "description": 3,
-    "category": 4,
-    "modifiers": 5,
-    "excluded": 6,
-    "coding map": 7,
+    "color": 4,
+    "category": 5,
+    "modifiers": 6,
+    "excluded": 7,
+    "coding map": 8,
 }
 """
 ETHOGRAM_FIELDS = [
@@ -255,10 +265,14 @@ BEHAVIOR_TYPES = [
 
 DEFAULT_BEHAVIOR_TYPE = "Point event"
 
-# fields for events table
-MEDIA_TW_EVENTS_FIELDS = ("time", "subject", "code", "type", "modifier", "comment")
+MEDIA_TW_EVENTS_FIELDS_DEFAULT = ("time", FRAME_INDEX, "subject", "code", "type", "modifier", "comment")
+
+
+# fields for events tablewidget
+MEDIA_TW_EVENTS_FIELDS = ("time", FRAME_INDEX, "subject", "code", "type", "modifier", "comment")
+# MEDIA_TW_EVENTS_FIELDS = ("time", "subject", "code", "type", "modifier", "comment")
 LIVE_TW_EVENTS_FIELDS = ("time", "subject", "code", "type", "modifier", "comment")
-IMAGES_TW_EVENTS_FIELDS = ("time", "subject", "code", "type", "modifier", "comment", "image index", "image path")
+IMAGES_TW_EVENTS_FIELDS = ("time", "subject", "code", "type", "modifier", "comment", IMAGE_INDEX, "image path")
 
 TW_EVENTS_FIELDS = {
     MEDIA: MEDIA_TW_EVENTS_FIELDS,
@@ -269,7 +283,7 @@ TW_EVENTS_FIELDS = {
     VIEWER_IMAGES: IMAGES_TW_EVENTS_FIELDS,
 }
 
-# create dictionaries
+# create dictionary index
 TW_OBS_FIELD = {}
 for observation_type in TW_EVENTS_FIELDS:
     TW_OBS_FIELD[observation_type] = {}
@@ -278,9 +292,9 @@ for observation_type in TW_EVENTS_FIELDS:
 
 
 # fields for project events list
-MEDIA_PJ_EVENTS_FIELDS = ("time", "subject", "code", "modifier", "comment")
-LIVE_PJ_EVENTS_FIELDS = ("time", "subject", "code", "modifier", "comment")
-IMAGES_PJ_EVENTS_FIELDS = ("time", "subject", "code", "modifier", "comment", "image index", "image path")
+MEDIA_PJ_EVENTS_FIELDS = (TIME, "subject", "code", "modifier", "comment", FRAME_INDEX)
+LIVE_PJ_EVENTS_FIELDS = (TIME, "subject", "code", "modifier", "comment")
+IMAGES_PJ_EVENTS_FIELDS = (TIME, "subject", "code", "modifier", "comment", "image index", "image path")
 
 PJ_EVENTS_FIELDS = {
     MEDIA: MEDIA_PJ_EVENTS_FIELDS,
@@ -308,7 +322,7 @@ EVENT_MODIFIER_FIELD_IDX = 3
 EVENT_COMMENT_FIELD_IDX = 4
 EVENT_STATUS_FIELD_IDX = 5
 # EVENT_IMAGEIDX_FIELD_IDX = 6
-EVENT_IMAGEPATH_FIELD_IDX = 7
+# EVENT_IMAGEPATH_FIELD_IDX = 7
 
 
 BEHAV_CODING_MAP_FIELDS = ["name", "Behavior codes"]
@@ -415,6 +429,8 @@ ALL_PLAYERS = [str(x + 1) for x in range(N_PLAYER)]
 VISUALIZE_SPECTROGRAM = "visualize_spectrogram"
 VISUALIZE_WAVEFORM = "visualize_waveform"
 
+IMAGE_DISPLAY_DURATION = "image_display_duration"
+
 # plot type
 WAVEFORM_PLOT = "waveform"
 SPECTROGRAM_PLOT = "spectrogram"
@@ -428,9 +444,6 @@ FRAME_TAB = 1
 
 SLIDER_MAXIMUM = 1000
 
-FRAME_BITMAP_FORMAT_LIST = ["JPG", "PNG"]
-FRAME_DEFAULT_BITMAP_FORMAT = "JPG"
-
 FRAME_DEFAULT_CACHE_SIZE = 1
 
 # modifiers
@@ -664,8 +677,20 @@ INIT_PARAM = {
     # TIME_BUDGET_FORMAT: DEFAULT_TIME_BUDGET_FORMAT,
     MPV_HWDEC: MPV_HWDEC_DEFAULT_VALUE,
     PROJECT_FILE_INDENTATION: PROJECT_FILE_INDENTATION_DEFAULT_VALUE,
+    f"{MEDIA} tw fields": MEDIA_TW_EVENTS_FIELDS_DEFAULT,
 }
 
+SDIS_EXT = "sds"
+TBS_EXT = "tbs"
+TSV_EXT = "tsv"
+CSV_EXT = "cvs"
+RDS_EXT = "rds"
+PANDAS_DF_EXT = "pkl"
+HMTL_EXT = "html"
+SQL_EXT = "sql"
+ODS_EXT = "ods"
+XLS_EXT = "xls"
+XLSX_EXT = "xlsx"
 
 # Output format
 TSV = "Tab Separated Values (*.tsv)"
@@ -684,18 +709,18 @@ TBS = "Timed Behavioral Sequences (*.tbs)"
 TEXT_FILE = "Text file"
 
 FILE_NAME_SUFFIX = {
-    TSV: "tsv",
-    CSV: "csv",
-    ODS: "ods",
-    ODS_WB: "ods",
-    XLSX: "xlsx",
-    XLSX_WB: "xlsx",
-    XLS: "xls",
-    HTML: "html",
-    PANDAS_DF: "pkl",
-    RDS: "rds",
-    SQL: "sql",
-    SDIS: "sds",
-    TBS: "tbs",
+    TSV: TSV_EXT,
+    CSV: CSV_EXT,
+    ODS: ODS_EXT,
+    ODS_WB: ODS_EXT,
+    XLSX: XLSX_EXT,
+    XLSX_WB: XLSX_EXT,
+    XLS: XLS_EXT,
+    HTML: HMTL_EXT,
+    PANDAS_DF: PANDAS_DF_EXT,
+    RDS: RDS_EXT,
+    SQL: SQL_EXT,
+    SDIS: SDIS_EXT,
+    TBS: TBS_EXT,
     TEXT_FILE: "cli",
 }
