@@ -41,7 +41,6 @@ from . import (
     observation_operations,
     preferences,
     project_import_export,
-    project_server,
     synthetic_time_budget,
     time_budget_widget,
     transitions,
@@ -78,8 +77,6 @@ def connections(self):
     self.action_remove_media_files_and_images_directories_path.triggered.connect(self.remove_media_files_path)
     self.action_remove_data_files_path.triggered.connect(self.remove_data_files_path)
 
-    self.actionSend_project.triggered.connect(lambda: project_server.send_project_via_socket(self))
-
     self.menuCreate_subtitles_2.triggered.connect(self.create_subtitles)
 
     self.actionPreferences.triggered.connect(lambda: preferences.preferences(self))
@@ -109,6 +106,9 @@ def connections(self):
     self.actionFilter_events.triggered.connect(lambda: event_operations.filter_events(self))
     self.actionShow_all_events.triggered.connect(lambda: event_operations.show_all_events(self))
 
+    # twevent header
+    self.actionConfigure_twEvents_columns.triggered.connect(self.configure_twevents_columns)
+
     self.actionExport_observations_list.triggered.connect(
         lambda: observation_operations.export_observations_list_clicked(self)
     )
@@ -168,7 +168,9 @@ def connections(self):
 
     # menu playback
     self.actionJumpTo.triggered.connect(self.jump_to)
+    self.action_deinterlace.triggered.connect(lambda: video_operations.deinterlace(self))
     self.actionZoom_level.triggered.connect(lambda: video_operations.zoom_level(self))
+    self.actionRotate_current_video.triggered.connect(lambda: video_operations.rotate_displayed_video(self))
     self.actionDisplay_subtitles.triggered.connect(lambda: video_operations.display_subtitles(self))
     self.actionVideo_equalizer.triggered.connect(lambda: video_equalizer.video_equalizer_show(self))
 
@@ -186,6 +188,7 @@ def connections(self):
 
     self.actionShow_data_files.triggered.connect(self.show_data_files)
     self.action_geometric_measurements.triggered.connect(lambda: geometric_measurement.show_widget(self))
+
     self.actionBehaviors_coding_map.triggered.connect(lambda: behaviors_coding_map.show_behaviors_coding_map(self))
 
     self.actionCoding_pad.triggered.connect(lambda: coding_pad.show_coding_pad(self))
@@ -287,6 +290,11 @@ def connections(self):
     self.actionShowAllSubjects.triggered.connect(self.show_all_subjects)
     self.twSubjects.addAction(self.actionShowAllSubjects)
 
+    # actions for twEvents horizontal header menu
+    tw_headers = self.twEvents.horizontalHeader()
+    tw_headers.setContextMenuPolicy(Qt.ActionsContextMenu)
+    tw_headers.addAction(self.actionConfigure_twEvents_columns)
+
     # Actions for twEvents menu
     self.twEvents.setContextMenuPolicy(Qt.ActionsContextMenu)
 
