@@ -26,6 +26,7 @@ import pathlib as pl
 import traceback
 import platform
 import datetime as dt
+import subprocess
 from decimal import Decimal as dec
 
 from PyQt5.QtCore import Qt, pyqtSignal, QT_VERSION_STR, PYQT_VERSION_STR
@@ -53,6 +54,7 @@ from PyQt5.QtWidgets import (
     QVBoxLayout,
     QWidget,
 )
+from PyQt5.QtGui import QFont
 
 from . import config as cfg
 from . import duration_widget
@@ -130,7 +132,7 @@ def error_message() -> None:
 def global_error_message(exception_type, exception_value, traceback_object):
     """
     global error management
-    save error using loggin.critical and append error message to ~/boris.log
+    save error using loggin.critical and stdout
     """
 
     error_text: str = (
@@ -143,41 +145,67 @@ def global_error_message(exception_type, exception_value, traceback_object):
     )
     error_text += "".join(traceback.format_exception(exception_type, exception_value, traceback_object))
 
-    logging.critical(error_text)
+    # system info
+    if sys.platform.startswith("win"):
+        systeminfo = subprocess.getoutput("systeminfo")
+    if sys.platform.startswith("linux"):
+        systeminfo = subprocess.getoutput("cat /etc/*rel*; uname -a")
 
-    # append to boris.log file
-    with open(pl.Path("~").expanduser() / "boris.log", "a") as f_out:
-        f_out.write(error_text + "\n")
-        f_out.write("-" * 80 + "\n")
+    logging.critical(error_text)
+    logging.critical(systeminfo)
+
+    # write error on stdout
+    """
+    print(error_text)
+    print("System info:")
+    print(systeminfo)
+    print("-" * 80 + "\n")
+    """
 
     # copy to clipboard
     cb = QApplication.clipboard()
     cb.clear(mode=cb.Clipboard)
-    cb.setText(error_text, mode=cb.Clipboard)
+    cb.setText(error_text + "\nSystem info:\n" + systeminfo, mode=cb.Clipboard)
 
     error_text: str = error_text.replace("\r\n", "\n").replace("\n", "<br>")
 
     text: str = (
-        f"<b>An error has occured</b>:<br><br>"
-        f"{error_text}<br>"
+        f"<b>An error has occured</b><br><br>"
         "to improve the software please report this problem at:<br>"
         '<a href="https://github.com/olivierfriard/BORIS/issues">'
         "https://github.com/olivierfriard/BORIS/issues</a><br>"
         "Please no screenshot, the error message was copied to the clipboard.<br><br>"
         "Thank you for your collaboration!"
+        "<br><br>"
+        "<pre>"
+        f"{error_text}"
+        "<hr>"
+        "<b>System info</b><br>"
+        f"{systeminfo}"
+        "</pre>"
     )
 
+    errorbox = Results_dialog()
+    errorbox.setWindowTitle("BORIS - An error occured")
+    errorbox.pbOK.setText("Abort")
+    errorbox.pbCancel.setVisible(True)
+    errorbox.pbCancel.setText("Ignore and try to continue")
+
+    errorbox.ptText.clear()
+    errorbox.ptText.appendHtml(text)
+
+    """
     errorbox = QMessageBox()
     errorbox.setWindowTitle("BORIS error occured")
     errorbox.setText(text)
     errorbox.setTextFormat(Qt.RichText)
     errorbox.setStandardButtons(QMessageBox.Abort)
-
     _ = errorbox.addButton("Ignore and try to continue", QMessageBox.RejectRole)
+    """
 
     ret = errorbox.exec_()
 
-    if ret == QMessageBox.Abort:
+    if ret == 1:  # Abort
         sys.exit(1)
 
 
@@ -203,28 +231,37 @@ class Video_overlay_dialog(QDialog):
         super().__init__()
 
         vlayout = QVBoxLayout()
-        vlayout.addWidget(QLabel("File"))
+        self.cb_player = QComboBox()
+        vlayout.addWidget(self.cb_player)
+
         hbox = QHBoxLayout()
+        hbox.addWidget(QLabel("Image file"))
         self.le_file_path = QLineEdit()
         hbox.addWidget(self.le_file_path)
+        vlayout.addLayout(hbox)
+
+        hbox = QHBoxLayout()
         self.pb_browse = QPushButton("Browse", self, clicked=self.browse)
+        hbox.addItem(QSpacerItem(241, 20, QSizePolicy.Expanding, QSizePolicy.Minimum))
         hbox.addWidget(self.pb_browse)
         vlayout.addLayout(hbox)
 
-        vlayout.addWidget(QLabel("Position: x,y"))
+        hbox = QHBoxLayout()
+        hbox.addWidget(QLabel("Position: x,y"))
         self.le_overlay_position = QLineEdit()
-        vlayout.addWidget(self.le_overlay_position)
+        hbox.addWidget(self.le_overlay_position)
+        vlayout.addLayout(hbox)
 
-        vlayout.addWidget(QLabel("Transparency %"))
+        hbox = QHBoxLayout()
+        hbox.addWidget(QLabel("Transparency %"))
         self.sb_overlay_transparency = QSpinBox()
         self.sb_overlay_transparency.setRange(0, 100)
         self.sb_overlay_transparency.setSingleStep(1)
-        self.sb_overlay_transparency.setValue(0)
-        vlayout.addWidget(self.sb_overlay_transparency)
-        self.sb_overlay_transparency.setEnabled(False)
+        self.sb_overlay_transparency.setValue(90)
+        hbox.addWidget(self.sb_overlay_transparency)
+        vlayout.addLayout(hbox)
 
-        self.cb_player = QComboBox()
-        vlayout.addWidget(self.cb_player)
+        # self.sb_overlay_transparency.setEnabled(False)
 
         hbox = QHBoxLayout()
         self.pb_cancel = QPushButton("Cancel", self, clicked=self.reject)
@@ -733,17 +770,16 @@ class Results_dialog(QDialog):
         hbox.addWidget(self.ptText)
 
         hbox2 = QHBoxLayout()
+        hbox2.addItem(QSpacerItem(241, 20, QSizePolicy.Expanding, QSizePolicy.Minimum))
+
         self.pbSave = QPushButton("Save results", clicked=self.save_results)
         hbox2.addWidget(self.pbSave)
 
-        hbox2.addItem(QSpacerItem(241, 20, QSizePolicy.Expanding, QSizePolicy.Minimum))
-
         self.pbCancel = QPushButton(cfg.CANCEL, clicked=self.reject)
         hbox2.addWidget(self.pbCancel)
         self.pbCancel.setVisible(False)
 
-        self.pbOK = QPushButton(cfg.OK)
-        self.pbOK.clicked.connect(self.accept)
+        self.pbOK = QPushButton(cfg.OK, clicked=self.accept)
         hbox2.addWidget(self.pbOK)
 
         hbox.addLayout(hbox2)
@@ -772,9 +808,9 @@ class Results_dialog(QDialog):
             self.done(cfg.SAVE_DATASET)
 
 
-class View_data_head(QDialog):
+class View_data(QDialog):
     """
-    widget for visualizing first rows of data file
+    widget for visualizing rows of data file
     """
 
     def __init__(self):
@@ -788,8 +824,18 @@ class View_data_head(QDialog):
         vbox.addWidget(self.lb)
 
         self.tw = QTableWidget()
+        self.tw.verticalHeader().hide()
         vbox.addWidget(self.tw)
 
+        vbox.addWidget(QLabel("Descriptive statistics"))
+
+        self.stats = QPlainTextEdit()
+        font = QFont()
+        font.setFamily("Monospace")
+        self.stats.setFont(font)
+
+        vbox.addWidget(self.stats)
+
         self.label = QLabel("Enter the column indices to plot (time, value) separated by comma (,)")
         vbox.addWidget(self.label)
 
@@ -798,6 +844,8 @@ class View_data_head(QDialog):
 
         hbox2 = QHBoxLayout()
 
+        hbox2.addItem(QSpacerItem(40, 20, QSizePolicy.Expanding, QSizePolicy.Minimum))
+
         self.pbCancel = QPushButton("Cancel", clicked=self.reject)
         hbox2.addWidget(self.pbCancel)
 
@@ -808,7 +856,7 @@ class View_data_head(QDialog):
 
         self.setLayout(vbox)
 
-        self.resize(540, 640)
+        self.resize(800, 640)
 
 
 class View_explore_project_results(QWidget):
