@@ -26,16 +26,16 @@ from . import config as cfg
 from . import dialog
 
 
-def add_image_overlay(self):
+def add_image_overlay(self) -> None:
     """
-    add an image overlay on video
+    add an image overlay on video from an image
     """
 
     logging.debug(f"function add_image_overlay")
 
     try:
         w = dialog.Video_overlay_dialog()
-        items = list([f"Player #{i + 1}" for i, _ in enumerate(self.dw_player)])
+        items = [f"Player #{i + 1}" for i, _ in enumerate(self.dw_player)]
         w.cb_player.addItems(items)
         if not w.exec_():
             return
@@ -57,11 +57,11 @@ def add_image_overlay(self):
         logging.debug("error in add_image_overlay function")
 
 
-def remove_image_overlay(self):
+def remove_image_overlay(self) -> None:
     """
     remove image overlay from all players
     """
-    keys_to_delete = []
+    keys_to_delete: list = []
     for n_player in self.pj[cfg.OBSERVATIONS][self.observationId][cfg.MEDIA_INFO].get(cfg.OVERLAY, {}):
         keys_to_delete.append(n_player)
         try:
