@@ -200,7 +200,7 @@ def load_observation(self, obs_id: str, mode: str = cfg.OBS_START) -> str:
     if obs_id not in self.pj[cfg.OBSERVATIONS]:
         return "Error: Observation not found"
 
-    if self.pj[cfg.OBSERVATIONS][obs_id][cfg.TYPE] not in [cfg.IMAGES, cfg.LIVE, cfg.MEDIA]:
+    if self.pj[cfg.OBSERVATIONS][obs_id][cfg.TYPE] not in (cfg.IMAGES, cfg.LIVE, cfg.MEDIA):
         return f"Error: Observation type {self.pj[cfg.OBSERVATIONS][obs_id][cfg.TYPE]} not found"
 
     self.observationId = obs_id
@@ -582,7 +582,6 @@ def new_observation(self, mode=cfg.NEW, obsId=""):
 
     observationWindow.pj = dict(self.pj)
     observationWindow.sw_observation_type.setCurrentIndex(0)  # no observation type
-    # observationWindow.sw_observation_type.setVisible(False)
     observationWindow.mode = mode
     observationWindow.mem_obs_id = obsId
     observationWindow.chunk_length = self.chunk_length
@@ -778,6 +777,11 @@ def new_observation(self, mode=cfg.NEW, obsId=""):
                 self.pj[cfg.OBSERVATIONS][obsId].get(cfg.VISUALIZE_WAVEFORM, False)
             )
 
+            # image display duration
+            observationWindow.sb_image_display_duration.setValue(
+                self.pj[cfg.OBSERVATIONS][obsId].get(cfg.IMAGE_DISPLAY_DURATION, 1)
+            )
+
             # plot data
             if cfg.PLOT_DATA in self.pj[cfg.OBSERVATIONS][obsId]:
                 if self.pj[cfg.OBSERVATIONS][obsId][cfg.PLOT_DATA]:
@@ -968,6 +972,11 @@ def new_observation(self, mode=cfg.NEW, obsId=""):
         self.pj[cfg.OBSERVATIONS][new_obs_id][
             cfg.VISUALIZE_WAVEFORM
         ] = observationWindow.cb_visualize_waveform.isChecked()
+        # image display duration
+        self.pj[cfg.OBSERVATIONS][new_obs_id][
+            cfg.IMAGE_DISPLAY_DURATION
+        ] = observationWindow.sb_image_display_duration.value()
+
         # time interval for observation
         self.pj[cfg.OBSERVATIONS][new_obs_id][
             cfg.OBSERVATION_TIME_INTERVAL
@@ -1289,7 +1298,7 @@ def initialize_new_media_observation(self) -> bool:
 
     # add all media files to media lists
     self.setDockOptions(QMainWindow.AnimatedDocks | QMainWindow.AllowNestedDocks)
-    self.dw_player = []
+    self.dw_player: list = []
     # create dock widgets for players
 
     for i in range(cfg.N_PLAYER):
@@ -1423,6 +1432,10 @@ def initialize_new_media_observation(self) -> bool:
         self.dw_player[i].player.keep_open = True
         self.dw_player[i].player.keep_open_pause = False
 
+        self.dw_player[i].player.image_display_duration = self.pj[cfg.OBSERVATIONS][self.observationId].get(
+            cfg.IMAGE_DISPLAY_DURATION, 1
+        )
+
         # position media
         if cfg.OBSERVATION_TIME_INTERVAL in self.pj[cfg.OBSERVATIONS][self.observationId]:
             self.seek_mediaplayer(
@@ -1435,6 +1448,12 @@ def initialize_new_media_observation(self) -> bool:
                 self.pj[cfg.OBSERVATIONS][self.observationId][cfg.MEDIA_INFO][cfg.ZOOM_LEVEL].get(n_player, 0)
             )
 
+        # restore rotation angle
+        if cfg.ROTATION_ANGLE in self.pj[cfg.OBSERVATIONS][self.observationId][cfg.MEDIA_INFO]:
+            self.dw_player[i].player.video_rotate = self.pj[cfg.OBSERVATIONS][self.observationId][cfg.MEDIA_INFO][
+                cfg.ROTATION_ANGLE
+            ].get(n_player, 0)
+
         # restore subtitle visibility
         if cfg.DISPLAY_MEDIA_SUBTITLES in self.pj[cfg.OBSERVATIONS][self.observationId][cfg.MEDIA_INFO]:
             self.dw_player[i].player.sub_visibility = self.pj[cfg.OBSERVATIONS][self.observationId][cfg.MEDIA_INFO][
@@ -1442,6 +1461,7 @@ def initialize_new_media_observation(self) -> bool:
             ].get(n_player, True)
 
         # restore overlays
+
         if cfg.OVERLAY in self.pj[cfg.OBSERVATIONS][self.observationId][cfg.MEDIA_INFO]:
             if n_player in self.pj[cfg.OBSERVATIONS][self.observationId][cfg.MEDIA_INFO][cfg.OVERLAY]:
                 self.overlays[i] = self.dw_player[i].player.create_image_overlay()
@@ -1460,7 +1480,6 @@ def initialize_new_media_observation(self) -> bool:
     self.state_behaviors_codes = tuple(util.state_behavior_codes(self.pj[cfg.ETHOGRAM]))
 
     video_operations.display_play_rate(self)
-    """self.lbSpeed.setText(f"Player rate: <b>x{self.play_rate:.3f}</b>")"""
 
     # spectrogram
     if (
@@ -1660,6 +1679,15 @@ def initialize_new_media_observation(self) -> bool:
 
     self.mpv_timer_out(value=0.0)
 
+    """
+    if self.pj[cfg.OBSERVATIONS][self.observationId][cfg.MEDIA_INFO].get(cfg.OVERLAY, {}):
+        for i in range(cfg.N_PLAYER):
+            # restore overlays
+            if str(i + 1) in self.pj[cfg.OBSERVATIONS][self.observationId][cfg.MEDIA_INFO][cfg.OVERLAY]:
+                self.overlays[i] = self.dw_player[i].player.create_image_overlay()
+                self.resize_dw(i)
+    """
+
     return True
 
 
@@ -1834,11 +1862,6 @@ def initialize_new_images_observation(self):
             self.saved_state = self.saveState()
             self.restoreState(self.saved_state)
 
-    """
-    self.twEvents.setColumnCount(len(cfg.IMAGES_TW_EVENTS_FIELDS))
-    self.twEvents.setHorizontalHeaderLabels(cfg.IMAGES_TW_EVENTS_FIELDS)
-    """
-
     self.extract_frame(self.dw_player[i])
     self.w_obs_info.setVisible(True)
 
@@ -1876,30 +1899,4 @@ def event2media_file_name(observation: dict, timestamp: dec) -> Optional[str]:
     else:
         video_file_name = None
 
-    """
-    player_idx_list = [
-        idx for idx, x in enumerate(cumul_media_durations) if cumul_media_durations[idx - 1] <= timestamp < x
-    ]
-
-    try:
-        print(f"{player_idx_list=}")
-    except:
-        pass
-
-    if len(player_idx_list):
-        player_idx = player_idx_list[0] - 1
-
-        try:
-            print(f"{player_idx=}")
-        except:
-            pass
-
-        video_file_name = observation[cfg.FILE]["1"][player_idx]
-    else:
-        player_idx = -1
-        video_file_name = None
-
-    print()
-    """
-
     return video_file_name
