@@ -35,8 +35,6 @@ from PyQt5.QtWidgets import (
     QInputDialog,
     QLabel,
     QLineEdit,
-    QListWidget,
-    QListWidgetItem,
     QMenu,
     QMessageBox,
     QPushButton,
@@ -44,6 +42,9 @@ from PyQt5.QtWidgets import (
     QSpacerItem,
     QTableWidgetItem,
     QVBoxLayout,
+    QColorDialog,
+    QTableWidget,
+    QAbstractItemView,
 )
 
 from . import add_modifier
@@ -73,11 +74,51 @@ class BehavioralCategories(QDialog):
         self.label.setText("Behavioral categories")
         self.vbox.addWidget(self.label)
 
-        self.lw = QListWidget()
+        # self.lw = QListWidget()
+        self.lw = QTableWidget()
+        self.lw.cellDoubleClicked[int, int].connect(self.lw_double_clicked)
 
         # add categories
-        for category in sorted(pj.get(cfg.BEHAVIORAL_CATEGORIES, [])):
-            self.lw.addItem(QListWidgetItem(category))
+        self.lw.setColumnCount(2)
+        self.lw.setHorizontalHeaderLabels(["Category name", "Color"])
+        # self.lw.verticalHeader().hide()
+        self.lw.setEditTriggers(QAbstractItemView.NoEditTriggers)
+
+        # self.lw.setSelectionBehavior(QAbstractItemView.SelectRows)
+        self.lw.setSelectionMode(QAbstractItemView.SingleSelection)
+
+        if cfg.BEHAVIORAL_CATEGORIES_CONF in pj:
+            self.lw.setRowCount(len(pj.get(cfg.BEHAVIORAL_CATEGORIES_CONF, {})))
+            behav_cat = pj.get(cfg.BEHAVIORAL_CATEGORIES_CONF, {})
+            for idx, key in enumerate(behav_cat.keys()):
+                # name
+                item = QTableWidgetItem()
+                item.setText(behav_cat[key]["name"])
+                # item.setFlags(Qt.ItemIsEnabled)
+                self.lw.setItem(idx, 0, item)
+                # color
+                item = QTableWidgetItem()
+                item.setText(behav_cat[key].get(cfg.COLOR, ""))
+                if behav_cat[key].get(cfg.COLOR, ""):
+                    item.setBackground(QColor(behav_cat[key].get(cfg.COLOR, "")))
+                else:
+                    item.setBackground(QColor(230, 230, 230))
+                # item.setFlags(Qt.ItemIsEnabled)
+                self.lw.setItem(idx, 1, item)
+        else:
+            self.lw.setRowCount(len(pj.get(cfg.BEHAVIORAL_CATEGORIES, [])))
+            for idx, category in enumerate(sorted(pj.get(cfg.BEHAVIORAL_CATEGORIES, []))):
+                item = QTableWidgetItem()
+                item.setText(category)
+                # item.setFlags(Qt.ItemIsEnabled)
+                self.lw.setItem(idx, 0, item)
+
+                item = QTableWidgetItem()
+                item.setText("")
+                # item.setFlags(Qt.ItemIsEnabled)
+                self.lw.setItem(idx, 1, item)
+
+            # self.lw.addItem(QListWidgetItem(category))
 
         self.vbox.addWidget(self.lw)
 
@@ -105,23 +146,63 @@ class BehavioralCategories(QDialog):
 
         self.setLayout(self.vbox)
 
+    def lw_double_clicked(self, row: int, column: int):
+        """
+        change color
+        """
+
+        if column != 1:
+            return
+        col_diag = QColorDialog()
+        col_diag.setOptions(QColorDialog.DontUseNativeDialog)
+
+        if self.lw.item(row, 1).text():
+            current_color = QColor(self.lw.item(row, 1).text())
+            if current_color.isValid():
+                col_diag.setCurrentColor(current_color)
+
+        if col_diag.exec_():
+            color = col_diag.currentColor()
+            if color.name() == "#000000":  # black -> delete color
+                self.lw.item(row, 1).setText("")
+                self.lw.item(row, 1).setBackground(QColor(230, 230, 230))
+            elif color.isValid():
+                self.lw.item(row, 1).setText(color.name())
+                self.lw.item(row, 1).setBackground(color)
+
     def add_behavioral_category(self):
         """
         add a behavioral category
         """
         category, ok = QInputDialog.getText(self, "New behavioral category", "Category name:")
         if ok:
-            self.lw.addItem(QListWidgetItem(category))
+            self.lw.insertRow(self.lw.rowCount())
+            item = QTableWidgetItem(category)
+            self.lw.setItem(self.lw.rowCount() - 1, 0, item)
+
+            item = QTableWidgetItem("")
+            # item.setFlags(Qt.ItemIsEnabled)
+            self.lw.setItem(self.lw.rowCount() - 1, 1, item)
 
     def remove_behavioral_category(self):
         """
         remove the selected behavioral category
         """
 
-        for SelectedItem in self.lw.selectedItems():
+        for selected_item in self.lw.selectedItems():
             # check if behavioral category is in use
-            category_to_remove = self.lw.item(self.lw.row(SelectedItem)).text().strip()
-            behaviors_in_category = []
+            if (
+                dialog.MessageDialog(
+                    cfg.programName,
+                    ("Confirm deletion of the behavioral category"),
+                    ("Confirm", cfg.CANCEL),
+                )
+                == cfg.CANCEL
+            ):
+                continue
+
+            category_to_remove = self.lw.item(self.lw.row(selected_item), 0).text().strip()
+            behaviors_in_category: list = []
             for idx in self.pj[cfg.ETHOGRAM]:
                 if (
                     cfg.BEHAVIOR_CATEGORY in self.pj[cfg.ETHOGRAM][idx]
@@ -130,16 +211,15 @@ class BehavioralCategories(QDialog):
                     behaviors_in_category.append(self.pj[cfg.ETHOGRAM][idx][cfg.BEHAVIOR_CODE])
             flag_remove = False
             if behaviors_in_category:
-
                 flag_remove = (
                     dialog.MessageDialog(
                         cfg.programName,
                         (
-                            "Some behavior belong to the <b>{1}</b> to remove:<br>"
-                            "{0}<br>"
+                            f"Some behavior belong to the <b>{category_to_remove}</b> to remove:<br>"
+                            f"{'<br>'.join(behaviors_in_category)}<br>"
                             "<br>Some features may not be available anymore.<br>"
-                        ).format("<br>".join(behaviors_in_category), category_to_remove),
-                        ["Remove category", cfg.CANCEL],
+                        ),
+                        ("Remove category", cfg.CANCEL),
                     )
                     == "Remove category"
                 )
@@ -148,17 +228,18 @@ class BehavioralCategories(QDialog):
                 flag_remove = True
 
             if flag_remove:
-                self.lw.takeItem(self.lw.row(SelectedItem))
+                self.lw.removeRow(self.lw.row(selected_item))
                 self.removed = category_to_remove
+
                 self.accept()
 
-    def pb_rename_category_clicked(self):
+    def pb_rename_category_clicked(self, row: int):
         """
         rename the selected behavioral category
         """
-        for SelectedItem in self.lw.selectedItems():
+        for selected_item in self.lw.selectedItems():
             # check if behavioral category is in use
-            category_to_rename = self.lw.item(self.lw.row(SelectedItem)).text().strip()
+            category_to_rename = self.lw.item(self.lw.row(selected_item), 0).text().strip()
             behaviors_in_category = []
             for idx in self.pj[cfg.ETHOGRAM]:
                 if (
@@ -187,7 +268,7 @@ class BehavioralCategories(QDialog):
                     self, "Rename behavioral category", "New category name:", QLineEdit.Normal, category_to_rename
                 )
                 if ok:
-                    self.lw.item(self.lw.indexFromItem(SelectedItem).row()).setText(new_category_name)
+                    self.lw.item(self.lw.indexFromItem(selected_item).row(), 0).setText(new_category_name)
                     # check behaviors belonging to the renamed category
                     self.renamed = [category_to_rename, new_category_name]
                     self.accept()
@@ -311,24 +392,24 @@ class projectDialog(QDialog, Ui_dlgProject):
         self.row_in_modification = -1
         self.flag_modified = False
 
-        for w in [
+        for w in (
             self.le_converter_name,
             self.le_converter_description,
             self.pteCode,
             self.pb_save_converter,
             self.pb_cancel_converter,
-        ]:
+        ):
             w.setEnabled(False)
 
         # disable widget for indep var setting
-        for widget in [
+        for widget in (
             self.leLabel,
             self.le_converter_description,
             self.cbType,
             self.lePredefined,
             self.dte_default_date,
             self.leSetValues,
-        ]:
+        ):
             widget.setEnabled(False)
 
         self.twBehaviors.horizontalHeader().sortIndicatorChanged.connect(self.sort_twBehaviors)
@@ -482,11 +563,11 @@ class projectDialog(QDialog, Ui_dlgProject):
                 )
 
             # convert modifier shortcuts
-            if self.twBehaviors.item(row, cfg.behavioursFields["modifiers"]).text():
+            if self.twBehaviors.item(row, cfg.behavioursFields[cfg.MODIFIERS]).text():
 
                 modifiers_dict = (
-                    eval(self.twBehaviors.item(row, cfg.behavioursFields["modifiers"]).text())
-                    if self.twBehaviors.item(row, cfg.behavioursFields["modifiers"]).text()
+                    eval(self.twBehaviors.item(row, cfg.behavioursFields[cfg.MODIFIERS]).text())
+                    if self.twBehaviors.item(row, cfg.behavioursFields[cfg.MODIFIERS]).text()
                     else {}
                 )
 
@@ -504,7 +585,7 @@ class projectDialog(QDialog, Ui_dlgProject):
                     except Exception:
                         logging.warning("error during conversion of modifier short cut to lower case")
 
-                self.twBehaviors.item(row, cfg.behavioursFields["modifiers"]).setText(str(modifiers_dict))
+                self.twBehaviors.item(row, cfg.behavioursFields[cfg.MODIFIERS]).setText(str(modifiers_dict))
 
     def convert_subjects_keys_to_lower_case(self):
         """
@@ -570,8 +651,8 @@ class projectDialog(QDialog, Ui_dlgProject):
                 self.pj[cfg.BEHAVIORS_CODING_MAP] = []
 
             bcm_code_not_found = []
-            existing_codes = [self.pj[cfg.ETHOGRAM][key]["code"] for key in self.pj[cfg.ETHOGRAM]]
-            for code in [bcm["areas"][key]["code"] for key in bcm["areas"]]:
+            existing_codes = [self.pj[cfg.ETHOGRAM][key][cfg.BEHAVIOR_CODE] for key in self.pj[cfg.ETHOGRAM]]
+            for code in [bcm["areas"][key][cfg.BEHAVIOR_CODE] for key in bcm["areas"]]:
                 if code not in existing_codes:
                     bcm_code_not_found.append(code)
 
@@ -589,7 +670,7 @@ class projectDialog(QDialog, Ui_dlgProject):
             self.twBehavCodingMap.setRowCount(self.twBehavCodingMap.rowCount() + 1)
 
             self.twBehavCodingMap.setItem(self.twBehavCodingMap.rowCount() - 1, 0, QTableWidgetItem(bcm["name"]))
-            codes = ", ".join([bcm["areas"][idx]["code"] for idx in bcm["areas"]])
+            codes = ", ".join([bcm["areas"][idx][cfg.BEHAVIOR_CODE] for idx in bcm["areas"]])
             self.twBehavCodingMap.setItem(self.twBehavCodingMap.rowCount() - 1, 1, QTableWidgetItem(codes))
 
     def remove_behaviors_coding_map(self):
@@ -648,8 +729,13 @@ class projectDialog(QDialog, Ui_dlgProject):
 
         if bc.exec_():
             self.pj[cfg.BEHAVIORAL_CATEGORIES] = []
-            for index in range(bc.lw.count()):
-                self.pj[cfg.BEHAVIORAL_CATEGORIES].append(bc.lw.item(index).text().strip())
+            self.pj[cfg.BEHAVIORAL_CATEGORIES_CONF] = {}
+            for index in range(bc.lw.rowCount()):
+                self.pj[cfg.BEHAVIORAL_CATEGORIES].append(bc.lw.item(index, 0).text().strip())
+                self.pj[cfg.BEHAVIORAL_CATEGORIES_CONF][str(index)] = {
+                    "name": bc.lw.item(index, 0).text().strip(),
+                    cfg.COLOR: bc.lw.item(index, 1).text(),
+                }
 
             # sort
             self.pj[cfg.BEHAVIORAL_CATEGORIES] = sorted(self.pj[cfg.BEHAVIORAL_CATEGORIES])
@@ -657,14 +743,15 @@ class projectDialog(QDialog, Ui_dlgProject):
             # check if behavior belong to removed category
             if bc.removed:
                 for row in range(self.twBehaviors.rowCount()):
-                    if self.twBehaviors.item(row, cfg.behavioursFields["category"]):
-                        if self.twBehaviors.item(row, cfg.behavioursFields["category"]).text() == bc.removed:
+                    if self.twBehaviors.item(row, cfg.behavioursFields[cfg.BEHAVIOR_CATEGORY]):
+                        if self.twBehaviors.item(row, cfg.behavioursFields[cfg.BEHAVIOR_CATEGORY]).text() == bc.removed:
                             if (
                                 dialog.MessageDialog(
                                     cfg.programName,
                                     (
                                         f"The <b>{self.twBehaviors.item(row, cfg.behavioursFields['code']).text()}</b> behavior belongs "
-                                        f"to a behavioral category <b>{self.twBehaviors.item(row, cfg.behavioursFields['category']).text()}</b> "
+                                        "to a behavioral category "
+                                        f"<b>{self.twBehaviors.item(row, cfg.behavioursFields['category']).text()}</b> "
                                         "that is no more in the behavioral categories list.<br><br>"
                                         "Remove the behavior from category?"
                                     ),
@@ -672,16 +759,22 @@ class projectDialog(QDialog, Ui_dlgProject):
                                 )
                                 == cfg.YES
                             ):
-                                self.twBehaviors.item(row, cfg.behavioursFields["category"]).setText("")
+                                self.twBehaviors.item(row, cfg.behavioursFields[cfg.BEHAVIOR_CATEGORY]).setText("")
             if bc.renamed:
                 for row in range(self.twBehaviors.rowCount()):
-                    if self.twBehaviors.item(row, cfg.behavioursFields["category"]):
-                        if self.twBehaviors.item(row, cfg.behavioursFields["category"]).text() == bc.renamed[0]:
-                            self.twBehaviors.item(row, cfg.behavioursFields["category"]).setText(bc.renamed[1])
+                    if self.twBehaviors.item(row, cfg.behavioursFields[cfg.BEHAVIOR_CATEGORY]):
+                        if (
+                            self.twBehaviors.item(row, cfg.behavioursFields[cfg.BEHAVIOR_CATEGORY]).text()
+                            == bc.renamed[0]
+                        ):
+                            self.twBehaviors.item(row, cfg.behavioursFields[cfg.BEHAVIOR_CATEGORY]).setText(
+                                bc.renamed[1]
+                            )
 
-    def twBehaviors_cellDoubleClicked(self, row, column):
+    def twBehaviors_cellDoubleClicked(self, row: int, column: int) -> None:
         """
         manage double-click on ethogram table:
+        * color
         * behavioral category
         * modifiers
         * exclusion
@@ -709,11 +802,15 @@ class projectDialog(QDialog, Ui_dlgProject):
         if column == cfg.behavioursFields["type"]:
             self.behavior_type_doubleclicked(row)
 
+        # color
+        if column == cfg.behavioursFields[cfg.COLOR]:
+            self.color_doubleclicked(row)
+
         # behavioral category
-        if column == cfg.behavioursFields["category"]:
+        if column == cfg.behavioursFields[cfg.BEHAVIOR_CATEGORY]:
             self.category_doubleclicked(row)
 
-        if column == cfg.behavioursFields["modifiers"]:
+        if column == cfg.behavioursFields[cfg.MODIFIERS]:
             # check if behavior has coding map
             if (
                 self.twBehaviors.item(row, cfg.behavioursFields["coding map"]) is not None
@@ -757,6 +854,29 @@ class projectDialog(QDialog, Ui_dlgProject):
 
             self.behaviorTypeChanged(row)
 
+    def color_doubleclicked(self, row: int) -> None:
+        """
+        select a color for behavior
+        Selecting black delete the color
+        """
+
+        col_diag = QColorDialog()
+        col_diag.setOptions(QColorDialog.ShowAlphaChannel | QColorDialog.DontUseNativeDialog)
+
+        if self.twBehaviors.item(row, cfg.behavioursFields[cfg.COLOR]).text():
+            current_color = QColor(self.twBehaviors.item(row, cfg.behavioursFields[cfg.COLOR]).text())
+            if current_color.isValid():
+                col_diag.setCurrentColor(current_color)
+
+        if col_diag.exec_():
+            color = col_diag.currentColor()
+            if color.name() == "#000000":  # black -> delete color
+                self.twBehaviors.item(row, cfg.behavioursFields[cfg.COLOR]).setText("")
+                self.twBehaviors.item(row, cfg.behavioursFields[cfg.COLOR]).setBackground(QColor(230, 230, 230))
+            elif color.isValid():
+                self.twBehaviors.item(row, cfg.behavioursFields[cfg.COLOR]).setText(color.name())
+                self.twBehaviors.item(row, cfg.behavioursFields[cfg.COLOR]).setBackground(color)
+
     def category_doubleclicked(self, row):
         """
         select category for behavior
@@ -764,8 +884,8 @@ class projectDialog(QDialog, Ui_dlgProject):
 
         categories = ["None"] + self.pj[cfg.BEHAVIORAL_CATEGORIES] if cfg.BEHAVIORAL_CATEGORIES in self.pj else ["None"]
 
-        if self.twBehaviors.item(row, cfg.behavioursFields["category"]).text() in categories:
-            selected = categories.index(self.twBehaviors.item(row, cfg.behavioursFields["category"]).text())
+        if self.twBehaviors.item(row, cfg.behavioursFields[cfg.BEHAVIOR_CATEGORY]).text() in categories:
+            selected = categories.index(self.twBehaviors.item(row, cfg.behavioursFields[cfg.BEHAVIOR_CATEGORY]).text())
         else:
             selected = 0
 
@@ -776,7 +896,7 @@ class projectDialog(QDialog, Ui_dlgProject):
         if ok and category:
             if category == "None":
                 category = ""
-            self.twBehaviors.item(row, cfg.behavioursFields["category"]).setText(category)
+            self.twBehaviors.item(row, cfg.behavioursFields[cfg.BEHAVIOR_CATEGORY]).setText(category)
 
     def check_variable_default_value(self, txt, varType):
         """
@@ -975,7 +1095,7 @@ class projectDialog(QDialog, Ui_dlgProject):
             return
 
         for row in range(self.twBehaviors.rowCount()):
-            if not self.twBehaviors.item(row, cfg.behavioursFields["code"]).text():
+            if not self.twBehaviors.item(row, cfg.behavioursFields[cfg.BEHAVIOR_CODE]).text():
                 QMessageBox.critical(
                     None,
                     cfg.programName,
@@ -1205,9 +1325,15 @@ class projectDialog(QDialog, Ui_dlgProject):
             for field in cfg.behavioursFields:
                 item = QTableWidgetItem(self.twBehaviors.item(row, cfg.behavioursFields[field]))
                 self.twBehaviors.setItem(self.twBehaviors.rowCount() - 1, cfg.behavioursFields[field], item)
-                if field in [cfg.TYPE, "category", "excluded", "coding map", "modifiers"]:
+                if field in (cfg.TYPE, "category", "excluded", "coding map", "modifiers"):
                     item.setFlags(Qt.ItemIsEnabled)
                     item.setBackground(QColor(230, 230, 230))
+                if field == cfg.COLOR:
+                    item.setFlags(Qt.ItemIsEnabled)
+                    if QColor(self.twBehaviors.item(row, cfg.behavioursFields[field]).text()).isValid():
+                        item.setBackground(QColor(self.twBehaviors.item(row, cfg.behavioursFields[field]).text()))
+                    else:
+                        item.setBackground(QColor(230, 230, 230))
         self.twBehaviors.scrollToBottom()
 
     def remove_behavior(self):
@@ -1231,7 +1357,6 @@ class projectDialog(QDialog, Ui_dlgProject):
             if dialog.MessageDialog(cfg.programName, "Remove the selected behavior?", [cfg.YES, cfg.CANCEL]) == cfg.YES:
 
                 # check if behavior already used in observations
-                flag_break = False
                 codeToDelete = self.twBehaviors.item(self.twBehaviors.selectedIndexes()[0].row(), 2).text()
                 for obs_id in self.pj[cfg.OBSERVATIONS]:
                     if codeToDelete in [
@@ -1261,7 +1386,7 @@ class projectDialog(QDialog, Ui_dlgProject):
             if field_type == cfg.TYPE:
                 item.setText("Point event")
             # no manual editing, gray back ground
-            if field_type in [cfg.TYPE, "category", "modifiers", "excluded", "coding map"]:
+            if field_type in (cfg.TYPE, cfg.COLOR, "category", cfg.MODIFIERS, "modifiers", "excluded", "coding map"):
                 item.setFlags(Qt.ItemIsEnabled)
                 item.setBackground(QColor(230, 230, 230))
             self.twBehaviors.setItem(self.twBehaviors.rowCount() - 1, cfg.behavioursFields[field_type], item)
@@ -1540,10 +1665,12 @@ class projectDialog(QDialog, Ui_dlgProject):
         for r in range(self.twBehaviors.rowCount()):
 
             if (
-                self.twBehaviors.item(r, cfg.behavioursFields["code"]).text()
-                != self.twBehaviors.item(r, cfg.behavioursFields["code"]).text().strip()
+                self.twBehaviors.item(r, cfg.behavioursFields[cfg.BEHAVIOR_CODE]).text()
+                != self.twBehaviors.item(r, cfg.behavioursFields[cfg.BEHAVIOR_CODE]).text().strip()
             ):
-                code_with_leading_trailing_spaces.append(self.twBehaviors.item(r, cfg.behavioursFields["code"]).text())
+                code_with_leading_trailing_spaces.append(
+                    self.twBehaviors.item(r, cfg.behavioursFields[cfg.BEHAVIOR_CODE]).text()
+                )
 
             if self.twBehaviors.item(r, cfg.behavioursFields["modifiers"]).text():
                 try:
@@ -1563,7 +1690,9 @@ class projectDialog(QDialog, Ui_dlgProject):
                 (
                     "<b>Warning!</b> Some leading and/or trailing spaces are present"
                     " in the following behaviors code(s):<br>"
-                    f"<b>{'<br>'.join([util.replace_leading_trailing_chars(x, ' ', '&#9608;') for x in code_with_leading_trailing_spaces])}</b><br><br>"
+                    "<b>"
+                    f"{'<br>'.join([util.replace_leading_trailing_chars(x, ' ', '&#9608;') for x in code_with_leading_trailing_spaces])}"
+                    "</b><br><br>"
                     "Do you want to remove the leading and trailing spaces (visualized as black boxes) from behaviors?<br><br>"
                     """<font color="red"><b>Be careful with this option"""
                     """ if you have already done observations!</b></font>"""
@@ -1579,13 +1708,13 @@ class projectDialog(QDialog, Ui_dlgProject):
                 cfg.programName,
                 (
                     "<b>Warning!</b> Some leading and/or trailing spaces are present"
-                    " in the following modifier(s):<br>"
-                    f"<b>{'<br>'.join([util.replace_leading_trailing_chars(x, ' ', '&#9608;') for x in set(modifiers_with_leading_trailing_spaces)])}</b><br><br>"
-                    "Do you want to remove the leading and trailing spaces (visualized as black boxes) from modifiers?<br><br>"
+                    " in the following modifier(s):<br><b>"
+                    f"{'<br>'.join([util.replace_leading_trailing_chars(x, ' ', '&#9608;') for x in set(modifiers_with_leading_trailing_spaces)])}"
+                    "</b><br><br>Do you want to remove the leading and trailing spaces (visualized as black boxes) from modifiers?<br><br>"
                     """<font color="red"><b>Be careful with this option"""
                     """ if you have already done observations!</b></font>"""
                 ),
-                [cfg.YES, cfg.NO, cfg.CANCEL],
+                (cfg.YES, cfg.NO, cfg.CANCEL),
             )
         if remove_leading_trailing_spaces_in_modifiers == cfg.CANCEL:
             return {cfg.CANCEL: True}
@@ -1597,7 +1726,10 @@ class projectDialog(QDialog, Ui_dlgProject):
                 if self.twBehaviors.item(r, cfg.behavioursFields[field]):
 
                     # check for | char in code
-                    if field == "code" and "|" in self.twBehaviors.item(r, cfg.behavioursFields[field]).text():
+                    if (
+                        field == cfg.BEHAVIOR_CODE
+                        and "|" in self.twBehaviors.item(r, cfg.behavioursFields[field]).text()
+                    ):
                         QMessageBox.warning(
                             self,
                             cfg.programName,
@@ -1640,7 +1772,7 @@ class projectDialog(QDialog, Ui_dlgProject):
                 else:
                     row[field] = ""
 
-            if (row["type"]) and (row["code"]):
+            if (row["type"]) and (row[cfg.BEHAVIOR_CODE]):
                 checked_ethogram[str(len(checked_ethogram))] = row
             else:
                 missing_data.append(str(r + 1))
