@@ -52,13 +52,13 @@ def export_project_as_pickle_object(pj: dict) -> None:
         QMessageBox.critical(
             None,
             cfg.programName,
-            f"Error during file saving.",
+            "Error during file saving.",
             QMessageBox.Ok | QMessageBox.Default,
             QMessageBox.NoButton,
         )
 
 
-def export_ethogram(self):
+def export_ethogram(self) -> None:
     """
     export ethogram in various format
     """
@@ -71,7 +71,7 @@ def export_ethogram(self):
         "Legacy Microsoft Excel Spreadsheet XLS (*.xls)",
         "HTML (*.html)",
     ]
-    file_formats = ["boris", "tsv", "csv", "ods", "xlsx", "xls", "html"]
+    file_formats = ["boris", cfg.TSV_EXT, "csv", "ods", "xlsx", "xls", "html"]
 
     filediag_func = QFileDialog().getSaveFileName
 
@@ -101,12 +101,12 @@ def export_ethogram(self):
 
     for r in range(self.twBehaviors.rowCount()):
         row = []
-        for field in ["code", cfg.TYPE, "description", "key", "category", "excluded"]:
+        for field in ("code", cfg.TYPE, "description", "key", cfg.COLOR, "category", "excluded"):
             row.append(self.twBehaviors.item(r, cfg.behavioursFields[field]).text())
 
         # modifiers
-        if self.twBehaviors.item(r, cfg.behavioursFields["modifiers"]).text():
-            modifiers_dict = eval(self.twBehaviors.item(r, cfg.behavioursFields["modifiers"]).text())
+        if self.twBehaviors.item(r, cfg.behavioursFields[cfg.MODIFIERS]).text():
+            modifiers_dict = eval(self.twBehaviors.item(r, cfg.behavioursFields[cfg.MODIFIERS]).text())
             modifiers_list = []
             for key in modifiers_dict:
                 if modifiers_dict[key]["values"]:
@@ -142,7 +142,7 @@ def export_ethogram(self):
             QMessageBox.critical(
                 None,
                 cfg.programName,
-                f"Error during file saving.",
+                "Error during file saving.",
                 QMessageBox.Ok | QMessageBox.Default,
                 QMessageBox.NoButton,
             )
@@ -153,19 +153,19 @@ def export_ethogram(self):
             QMessageBox.critical(None, cfg.programName, msg, QMessageBox.Ok | QMessageBox.Default, QMessageBox.NoButton)
 
 
-def export_subjects(self):
+def export_subjects(self) -> None:
     """
     export the subjetcs list in various format
     """
     extended_file_formats = [
-        "Tab Separated Values (*.tsv)",
-        "Comma Separated Values (*.csv)",
-        "Open Document Spreadsheet ODS (*.ods)",
-        "Microsoft Excel Spreadsheet XLSX (*.xlsx)",
-        "Legacy Microsoft Excel Spreadsheet XLS (*.xls)",
-        "HTML (*.html)",
+        cfg.TSV,
+        cfg.CSV,
+        cfg.ODS,
+        cfg.XLSX,
+        cfg.XLS,
+        cfg.HMTL,
     ]
-    file_formats = ["tsv", "csv", "ods", "xlsx", "xls", "html"]
+    file_formats = [cfg.TSV_EXT, "csv", "ods", "xlsx", "xls", "html"]
 
     filediag_func = QFileDialog().getSaveFileName
 
@@ -356,7 +356,7 @@ def import_ethogram_from_dict(self, project: dict):
                 item.setBackground(QColor(230, 230, 230))
 
             else:
-                if field == "modifiers" and isinstance(project[cfg.ETHOGRAM][i][field], str):
+                if field == cfg.MODIFIERS and isinstance(project[cfg.ETHOGRAM][i][field], str):
                     modif_set_dict = {}
                     if project[cfg.ETHOGRAM][i][field]:
                         modif_set_list = project[cfg.ETHOGRAM][i][field].split("|")
