@@ -22,9 +22,18 @@ This file is part of BORIS.
 
 import re
 
-from PyQt5.QtCore import *
-from PyQt5.QtGui import *
-from PyQt5.QtWidgets import *
+from PyQt5.QtCore import Qt, QEvent
+from PyQt5.QtWidgets import (
+    QDialog,
+    QVBoxLayout,
+    QLabel,
+    QListWidget,
+    QHBoxLayout,
+    QLineEdit,
+    QPushButton,
+    QListWidgetItem,
+
+    QSizePolicy,QSpacerItem, QAbstractItemView, QMessageBox)
 
 from . import config as cfg
 from . import utilities as util
@@ -32,7 +41,6 @@ from . import utilities as util
 
 class ModifiersList(QDialog):
     def __init__(self, code: str, modifiers_dict: dict, currentModifier: str):
-
         super().__init__()
         self.setWindowTitle(cfg.programName)
         self.setWindowFlags(Qt.WindowStaysOnTopHint)
@@ -42,14 +50,15 @@ class ModifiersList(QDialog):
 
         V1layout = QVBoxLayout()
         label = QLabel()
-        label.setText(f"Choose the modifier{'s' * (len(self.modifiers_dict) > 1)} for <b>{code}</b> behavior")
+        label.setText(
+            f"Choose the modifier{'s' * (len(self.modifiers_dict) > 1)} for <b>{code}</b> behavior"
+        )
         V1layout.addWidget(label)
 
         Hlayout = QHBoxLayout()
         self.modifiersSetNumber = 0
 
         for idx in util.sorted_keys(modifiers_dict):
-
             if self.modifiers_dict[idx]["type"] not in [
                 cfg.SINGLE_SELECTION,
                 cfg.MULTI_SELECTION,
@@ -65,7 +74,10 @@ class ModifiersList(QDialog):
             lb.setText(f"Modifier <b>{self.modifiers_dict[idx]['name']}</b>")
             V2layout.addWidget(lb)
 
-            if self.modifiers_dict[idx]["type"] in [cfg.SINGLE_SELECTION, cfg.MULTI_SELECTION]:
+            if self.modifiers_dict[idx]["type"] in [
+                cfg.SINGLE_SELECTION,
+                cfg.MULTI_SELECTION,
+            ]:
                 lw = QListWidget()
                 self.modifiers_dict[idx]["widget"] = lw
                 lw.setObjectName(f"lw_modifiers_({self.modifiers_dict[idx]['type']})")
@@ -83,9 +95,9 @@ class ModifiersList(QDialog):
 
                         # previously selected
                         try:
-                            if currentModifierList != [""] and re.sub(" \(.\)", "", modifier) in currentModifierList[
-                                int(idx)
-                            ].split(","):
+                            if currentModifierList != [""] and re.sub(
+                                " \(.\)", "", modifier
+                            ) in currentModifierList[int(idx)].split(","):
                                 item.setCheckState(Qt.Checked)
                         except Exception:  # for old projects due to a fixed bug
                             pass
@@ -96,7 +108,8 @@ class ModifiersList(QDialog):
                         try:
                             if (
                                 currentModifierList != [""]
-                                and re.sub(" \(.\)", "", modifier) == currentModifierList[int(idx)]
+                                and re.sub(" \(.\)", "", modifier)
+                                == currentModifierList[int(idx)]
                             ):
                                 item.setSelected(True)
                         except Exception:  # for old projects due to a fixed bug
@@ -107,13 +120,18 @@ class ModifiersList(QDialog):
                 le = QLineEdit()
                 self.modifiers_dict[idx]["widget"] = le
 
-                if currentModifierList != [""] and currentModifierList[int(idx)] != "None":
+                if (
+                    currentModifierList != [""]
+                    and currentModifierList[int(idx)] != "None"
+                ):
                     le.setText(currentModifierList[int(idx)])
 
                 V2layout.addWidget(le)
 
                 # vertical spacer
-                spacerItem = QSpacerItem(20, 40, QSizePolicy.Minimum, QSizePolicy.Expanding)
+                spacerItem = QSpacerItem(
+                    20, 40, QSizePolicy.Minimum, QSizePolicy.Expanding
+                )
                 V2layout.addItem(spacerItem)
 
             Hlayout.addLayout(V2layout)
@@ -151,13 +169,14 @@ class ModifiersList(QDialog):
                 return False
 
             # accept and close dialog if enter pressed
-            if ek == Qt.Key_Enter or ek == Qt.Key_Return:  # enter or enter from numeric pad
+            if (
+                ek == Qt.Key_Enter or ek == Qt.Key_Return
+            ):  # enter or enter from numeric pad
                 self.accept()
                 return True
 
             for widget in self.children():
                 if "lw_modifiers" in widget.objectName():
-
                     if self.modifiersSetNumber == 1:
                         # check if modifiers have code
                         for index in range(widget.count()):
@@ -166,24 +185,43 @@ class ModifiersList(QDialog):
                         else:
                             # modifiers have no associated code: the modifier starting with hit key will be selected
                             if ek not in [Qt.Key_Down, Qt.Key_Up]:
-
                                 if (
-                                    ek == Qt.Key_Space and f"({cfg.MULTI_SELECTION})" in widget.objectName()
+                                    ek == Qt.Key_Space
+                                    and f"({cfg.MULTI_SELECTION})"
+                                    in widget.objectName()
                                 ):  # checking using SPACE bar
-                                    if widget.item(widget.currentRow()).checkState() == Qt.Checked:
-                                        widget.item(widget.currentRow()).setCheckState(Qt.Unchecked)
+                                    if (
+                                        widget.item(widget.currentRow()).checkState()
+                                        == Qt.Checked
+                                    ):
+                                        widget.item(widget.currentRow()).setCheckState(
+                                            Qt.Unchecked
+                                        )
                                     else:
-                                        widget.item(widget.currentRow()).setCheckState(Qt.Checked)
+                                        widget.item(widget.currentRow()).setCheckState(
+                                            Qt.Checked
+                                        )
 
                                 else:
                                     for index in range(widget.count()):
-                                        if widget.item(index).text().upper().startswith(ek_text.upper()):
+                                        if (
+                                            widget.item(index)
+                                            .text()
+                                            .upper()
+                                            .startswith(ek_text.upper())
+                                        ):
                                             widget.setCurrentRow(index)
-                                            widget.scrollToItem(widget.item(index), QAbstractItemView.EnsureVisible)
+                                            widget.scrollToItem(
+                                                widget.item(index),
+                                                QAbstractItemView.EnsureVisible,
+                                            )
                                             return True
                             else:  # up / down keys
                                 try:
-                                    if ek == Qt.Key_Down and widget.currentRow() < widget.count() - 1:
+                                    if (
+                                        ek == Qt.Key_Down
+                                        and widget.currentRow() < widget.count() - 1
+                                    ):
                                         widget.setCurrentRow(widget.currentRow() + 1)
                                     if ek == Qt.Key_Up and widget.currentRow() > 0:
                                         widget.setCurrentRow(widget.currentRow() - 1)
@@ -191,9 +229,11 @@ class ModifiersList(QDialog):
                                     return
 
                     for index in range(widget.count()):
-
                         if ek in cfg.function_keys:
-                            if f"({cfg.function_keys[ek]})" in widget.item(index).text().upper():
+                            if (
+                                f"({cfg.function_keys[ek]})"
+                                in widget.item(index).text().upper()
+                            ):
                                 if f"({cfg.SINGLE_SELECTION})" in widget.objectName():
                                     widget.item(index).setSelected(True)
                                     # close dialog if one set of modifiers
@@ -208,7 +248,6 @@ class ModifiersList(QDialog):
                                         widget.item(index).setCheckState(Qt.Checked)
 
                         if ek < 1114112 and f"({ek_text})" in widget.item(index).text():
-
                             if f"({cfg.SINGLE_SELECTION})" in widget.objectName():
                                 widget.item(index).setSelected(True)
                                 # close dialog if one set of modifiers
@@ -231,17 +270,27 @@ class ModifiersList(QDialog):
         get modifiers
         returns list of selected modifiers
         """
-        modifiers = []
+        
         for idx in util.sorted_keys(self.modifiers_dict):
-
-            if self.modifiers_dict[idx]["type"] in [cfg.SINGLE_SELECTION, cfg.MULTI_SELECTION, cfg.NUMERIC_MODIFIER]:
+            if self.modifiers_dict[idx]["type"] in [
+                cfg.SINGLE_SELECTION,
+                cfg.MULTI_SELECTION,
+                cfg.NUMERIC_MODIFIER,
+            ]:
                 self.modifiers_dict[idx]["selected"] = []
 
             if self.modifiers_dict[idx]["type"] == cfg.MULTI_SELECTION:
                 for j in range(self.modifiers_dict[idx]["widget"].count()):
-                    if self.modifiers_dict[idx]["widget"].item(j).checkState() == Qt.Checked:
+                    if (
+                        self.modifiers_dict[idx]["widget"].item(j).checkState()
+                        == Qt.Checked
+                    ):
                         self.modifiers_dict[idx]["selected"].append(
-                            re.sub(" \(.*\)", "", self.modifiers_dict[idx]["widget"].item(j).text())
+                            re.sub(
+                                " \(.*\)",
+                                "",
+                                self.modifiers_dict[idx]["widget"].item(j).text(),
+                            )
                         )
 
                 if not self.modifiers_dict[idx]["selected"]:
@@ -249,11 +298,15 @@ class ModifiersList(QDialog):
 
             if self.modifiers_dict[idx]["type"] == cfg.SINGLE_SELECTION:
                 for item in self.modifiers_dict[idx]["widget"].selectedItems():
-                    self.modifiers_dict[idx]["selected"].append(re.sub(" \(.*\)", "", item.text()))
+                    self.modifiers_dict[idx]["selected"].append(
+                        re.sub(" \(.*\)", "", item.text())
+                    )
 
             if self.modifiers_dict[idx]["type"] == cfg.NUMERIC_MODIFIER:
                 self.modifiers_dict[idx]["selected"] = (
-                    self.modifiers_dict[idx]["widget"].text() if self.modifiers_dict[idx]["widget"].text() else "None"
+                    self.modifiers_dict[idx]["widget"].text()
+                    if self.modifiers_dict[idx]["widget"].text()
+                    else "None"
                 )
         """
         for widget in self.children():
@@ -269,17 +322,18 @@ class ModifiersList(QDialog):
         return self.modifiers_dict
 
     def pbOK_clicked(self):
-
         for idx in util.sorted_keys(self.modifiers_dict):
             if self.modifiers_dict[idx]["type"] == cfg.NUMERIC_MODIFIER:
                 if self.modifiers_dict[idx]["widget"].text():
                     try:
-                        val = float(self.modifiers_dict[idx]["widget"].text())
+                        _ = float(self.modifiers_dict[idx]["widget"].text())
                     except Exception:
                         QMessageBox.warning(
                             self,
                             cfg.programName,
-                            "<b>{}</b> is not a numeric value".format(self.modifiers_dict[idx]["widget"].text()),
+                            "<b>{}</b> is not a numeric value".format(
+                                self.modifiers_dict[idx]["widget"].text()
+                            ),
                         )
                         return
 
