@@ -19,7 +19,6 @@ Copyright 2012-2023 Olivier Friard
   MA 02110-1301, USA.
 """
 
-from cmath import isnan
 import csv
 import datetime
 import hashlib
@@ -37,10 +36,9 @@ import wave
 from decimal import Decimal as dec
 from decimal import getcontext, ROUND_DOWN
 from shutil import copyfile
-from typing import Union
+from typing import Union, Tuple
 
 import numpy as np
-from PyQt5.QtGui import qRgb
 from PyQt5.QtGui import QPixmap, QImage
 
 from PIL.ImageQt import Image
@@ -66,13 +64,12 @@ def error_info(exc_info: tuple) -> tuple:
     return (f"{exc_type}: {exc_obj}", fname, exc_tb.tb_lineno)
 
 
-def pil2pixmap(im) -> QPixmap:
+def pil2pixmap(im: Image) -> QPixmap:
     """
     convert PIL image to pixmap
     see https://stackoverflow.com/questions/34697559/pil-image-to-qpixmap-conversion-issue
     """
 
-    # print(im.mode)
     if im.mode == "RGB":
         r, g, b = im.split()
         im = Image.merge("RGB", (b, g, r))
@@ -118,7 +115,7 @@ def return_file_header(file_name: str, row_number: int = 5) -> list:
     Returns:
         list: first row_number row(s) of file_name
     """
-    header = []
+    header: list = []
     try:
         with open(file_name) as f_in:
             for _ in range(row_number):
@@ -128,6 +125,35 @@ def return_file_header(file_name: str, row_number: int = 5) -> list:
     return header
 
 
+def return_file_header_footer(file_name: str, file_row_number: int = 0, row_number: int = 5) -> Tuple[list, list]:
+    """
+    return file header and footer
+
+    Args:
+        file_name (str): path of file
+        file_row_number (int): total rows number of file
+        row_number (int): number of rows to return
+
+    Returns:
+        list: first row_number row(s) of file_name
+    """
+    header: list = []
+    footer: list = []
+    try:
+        row_idx: int = 0
+        with open(file_name, "rt") as f_in:
+            for row in f_in:
+                if row_idx < row_number:
+                    header.append(row.strip())
+                if file_row_number > row_number * 2 and (row_idx >= file_row_number - row_number):
+                    footer.append(row.strip())
+                row_idx += 1
+
+    except Exception:
+        return [], []
+    return header, footer
+
+
 def bytes_to_str(b: bytes) -> str:
     """
     Translate bytes to string.
@@ -149,7 +175,7 @@ def bytes_to_str(b: bytes) -> str:
         return b
 
 
-def convertTime(time_format: str, sec: float) -> str:
+def convertTime(time_format: str, sec: Union[float, dec]) -> str:
     """
     convert time in base at the current format (S or HHMMSS)
 
@@ -172,6 +198,18 @@ def convertTime(time_format: str, sec: float) -> str:
     return None
 
 
+def dynamic_time_format(sec: Union[float, dec], cutoff: dec, time_format: str) -> str:
+    """
+    returns time in seconds if <= cutoff else in HH:MM:SS.ZZZ format
+    """
+    if cutoff == 0:
+        return convertTime(time_format, sec)
+    if sec <= cutoff:
+        return f"{sec:.3f}"
+    else:
+        return seconds2time(sec)
+
+
 def convert_time_to_decimal(pj: dict) -> dict:
     """
     convert time of project from float to decimal
@@ -193,6 +231,13 @@ def convert_time_to_decimal(pj: dict) -> dict:
     return pj
 
 
+def count_media_file(media_files: dict) -> int:
+    """
+    count number of media file for observation
+    """
+    return sum([len(media_files[idx]) for idx in media_files])
+
+
 def file_content_md5(file_name: str) -> str:
     """
     returns the MD5 sum of file content
@@ -207,9 +252,11 @@ def file_content_md5(file_name: str) -> str:
         return ""
 
 
-def txt2np_array(file_name: str, columns_str: str, substract_first_value: str, converters=None, column_converter=None):
+def txt2np_array(
+    file_name: str, columns_str: str, substract_first_value: str, converters=None, column_converter=None
+) -> Tuple[bool, str, np.array]:
     """
-    read a txt file (tsv or csv) and return np array with passed columns
+    read a txt file (tsv or csv) and return a np array with columns cited in columns_str
 
     Args:
         file_name (str): path of the file to load in numpy array
@@ -236,10 +283,9 @@ def txt2np_array(file_name: str, columns_str: str, substract_first_value: str, c
         return False, f"Problem with columns {columns_str}", np.array([])
 
     # check converters
-    np_converters = {}
+    np_converters: dict = {}
     for column_idx in column_converter:
         if column_converter[column_idx] in converters:
-
             conv_name = column_converter[column_idx]
 
             function = f"""def {conv_name}(INPUT):\n"""
@@ -261,17 +307,27 @@ def txt2np_array(file_name: str, columns_str: str, substract_first_value: str, c
     # snif txt file
     try:
         with open(file_name) as csvfile:
-            buff = csvfile.read(1024)
+            buff = csvfile.read(4096)
             snif = csv.Sniffer()
             dialect = snif.sniff(buff)
-            has_header = snif.has_header(buff)
+            """has_header = snif.has_header(buff)"""
+        # count number of header rows
+        header_rows_nb = 0
+        csv.register_dialect("dialect", dialect)
+        with open(file_name, "r") as f:
+            reader = csv.reader(f, dialect="dialect")
+            for row in reader:
+                if sum([isinstance(intfloatstr(x), str) for x in row]) == len(row):
+                    header_rows_nb += 1
+
     except Exception:
         return False, f"{sys.exc_info()[1]}", np.array([])
 
     try:
         data = np.loadtxt(
-            file_name, delimiter=dialect.delimiter, usecols=columns, skiprows=has_header, converters=np_converters
+            file_name, delimiter=dialect.delimiter, usecols=columns, skiprows=header_rows_nb, converters=np_converters
         )
+
     except Exception:
         return False, f"{sys.exc_info()[1]}", np.array([])
 
@@ -298,6 +354,31 @@ def versiontuple(version_str: str):
     return tuple(filled)
 
 
+def behavior_user_color(ethogram: dict, behavior_code: str) -> Union[str, None]:
+    """
+    returns the color of behavior if defined else None
+    """
+    for x in ethogram:
+        if ethogram[x][cfg.BEHAVIOR_CODE] == behavior_code:
+            if ethogram[x].get(cfg.COLOR, None) == "":
+                return None
+            else:
+                return ethogram[x].get(cfg.COLOR, None)
+
+    return None
+
+
+def behav_category_user_color(behavioral_categories: dict, name: str) -> Union[str, None]:
+    """
+    returns the color of the behavioral category if defined else None
+    """
+    for key in behavioral_categories:
+        if behavioral_categories[key]["name"] == name:
+            return behavioral_categories[key].get(cfg.COLOR, None)
+
+    return None
+
+
 def state_behavior_codes(ethogram: dict) -> list:
     """
     behavior codes defined as STATE event
@@ -348,7 +429,6 @@ def group_events(pj: dict, obs_id: str, include_modifiers: bool = False) -> dict
         intervals_behav = {}
 
         for event in pj[cfg.OBSERVATIONS][obs_id][cfg.EVENTS]:
-
             time_ = event[cfg.EVENT_TIME_FIELD_IDX]
             subject = event[cfg.EVENT_SUBJECT_FIELD_IDX]
             code = event[cfg.EVENT_BEHAVIOR_FIELD_IDX]
@@ -356,9 +436,7 @@ def group_events(pj: dict, obs_id: str, include_modifiers: bool = False) -> dict
 
             # check if code is state
             if code in state_events_list:
-
                 if (subject, code, modifier) in mem_behav and mem_behav[(subject, code, modifier)]:
-
                     if (subject, code, modifier) not in intervals_behav:
                         intervals_behav[(subject, code, modifier)] = []
                     intervals_behav[(subject, code, modifier)].append((mem_behav[(subject, code, modifier)], time_))
@@ -395,15 +473,15 @@ def get_current_states_modifiers_by_subject(
     Returns:
         dict: current states by subject. dict of list
     """
-    current_states = {}
+    current_states: dict = {}
     if time.is_nan():
         for idx in subjects:
             current_states[idx] = []
         return current_states
 
     # check if time contains NA
-    if [x for x in events if events[cfg.EVENT_TIME_FIELD_IDX][cfg.EVENT_TIME_FIELD_IDX].is_nan()]:
-        check_index = cfg.PJ_OBS_FIELDS[cfg.IMAGES]["image index"]
+    if [x for x in events if x[cfg.EVENT_TIME_FIELD_IDX].is_nan()]:
+        check_index = cfg.PJ_OBS_FIELDS[cfg.IMAGES][cfg.IMAGE_INDEX]
     else:
         check_index = cfg.EVENT_TIME_FIELD_IDX
 
@@ -555,35 +633,43 @@ def check_txt_file(file_name: str) -> dict:
     try:
         # snif txt file
         with open(file_name) as csvfile:
-            buff = csvfile.read(1024)
+            buff = csvfile.read(4096)
             snif = csv.Sniffer()
             dialect = snif.sniff(buff)
             has_header = snif.has_header(buff)
 
         csv.register_dialect("dialect", dialect)
-        rows_len = []
+        rows_len: list = []
         with open(file_name, "r") as f:
             reader = csv.reader(f, dialect="dialect")
             for row in reader:
-
                 if not row:
                     continue
+                """
                 if len(row) not in rows_len:
                     rows_len.append(len(row))
                     if len(rows_len) > 1:
                         break
+                """
+                rows_len.append(len(row))
+
+        rows_number = len(rows_len)
+        rows_uniq_len = set(rows_len)
 
         # test if file empty
-        if not len(rows_len):
+        if not rows_uniq_len:
             return {"error": "The file is empty"}
 
-        if len(rows_len) == 1 and rows_len[0] >= 2:
-            return {"homogeneous": True, "fields number": rows_len[0], "separator": dialect.delimiter}
-
-        if len(rows_len) > 1:
-            return {"homogeneous": False}
+        if len(rows_uniq_len) == 1:
+            return {
+                "homogeneous": True,
+                "fields number": rows_len[0],
+                "separator": dialect.delimiter,
+                "rows number": rows_number,
+                "has header": has_header,
+            }
         else:
-            return {"homogeneous": True, "fields number": rows_len[0], "separator": dialect.delimiter}
+            return {"homogeneous": False}
     except Exception:
         return {"error": str(sys.exc_info()[1])}
 
@@ -639,21 +725,20 @@ def decimal_default(obj):
     raise TypeError
 
 
-def complete(l: list, max_: int) -> list:
+def complete(lst: list, max_: int) -> list:
     """
     complete list with empty string ("") until len = max
 
     Args:
-        l (list): list to complete
+        lst (list): list to complete
         max_ (int): number of items to reach
 
     Returns:
         list: list completed to max_ items with empty string ("")
     """
-    while len(l) < max_:
-        l.append("")
-    # l.extend([""] * (max_ - len(l)))
-    return l
+    while len(lst) < max_:
+        lst.append("")
+    return lst
 
 
 def datetime_iso8601(dt) -> str:
@@ -772,7 +857,6 @@ def mem_info():
             return True, {"msg": error_info(sys.exc_info())[0]}
 
     if sys.platform.startswith("win"):
-
         try:
             output = subprocess.run(
                 ["wmic", "computersystem", "get", "TotalPhysicalMemory", "/", "Value"], stdout=subprocess.PIPE
@@ -856,7 +940,7 @@ def seconds2time(sec: dec) -> str:
     """
 
     if math.isnan(sec):
-        return "NA"
+        return cfg.NA
 
     if sec > 1_600_000_000:  # epoch time
         t = datetime.datetime.fromtimestamp(float(sec))
@@ -957,7 +1041,6 @@ def check_ffmpeg_path():
     """
 
     if sys.platform.startswith("linux") or sys.platform.startswith("darwin"):
-
         ffmpeg_path = pl.Path("")
         # search embedded ffmpeg
         if sys.argv[0].endswith("start_boris.py"):
@@ -977,7 +1060,6 @@ def check_ffmpeg_path():
             return False, "FFmpeg is not available"
 
     if sys.platform.startswith("win"):
-
         ffmpeg_path = pl.Path("")
         # search embedded ffmpeg
         if sys.argv[0].endswith("start_boris.py"):
@@ -1037,12 +1119,12 @@ def ffprobe_media_analysis(ffmpeg_bin: str, file_name: str) -> dict:
     p = subprocess.Popen(command, stdout=subprocess.PIPE, stderr=subprocess.PIPE, shell=True)
     out, error = p.communicate()
     if error:
-        return {"error": error.decode("utf-8")}
+        return {"error": f"{error}"}
 
     try:
         hasVideo = False
         hasAudio = False
-        bitrate = None
+        '''bitrate = None'''
         video_bitrate = None
         audio_bitrate = []
         resolution = None
@@ -1059,12 +1141,12 @@ def ffprobe_media_analysis(ffmpeg_bin: str, file_name: str) -> dict:
             size = int(video_param["format"]["size"])
 
         for stream in video_param["streams"]:
-
             if stream["codec_type"] == "video":
                 hasVideo = True
                 video_bitrate = int(stream["bit_rate"]) if "bit_rate" in stream else None
                 resolution = f"{stream['width']}x{stream['height']}"
 
+                """
                 if "avg_frame_rate" in stream:
                     if stream["avg_frame_rate"] == "0/0":
                         fps = 0
@@ -1073,9 +1155,25 @@ def ffprobe_media_analysis(ffmpeg_bin: str, file_name: str) -> dict:
                             fps = eval(stream["avg_frame_rate"])
                         except Exception:
                             fps = 0
+                """
+                if "r_frame_rate" in stream:
+                    if stream["r_frame_rate"] == "0/0":
+                        fps = 0
+                    else:
+                        try:
+                            fps = eval(stream["r_frame_rate"])
+                        except Exception:
+                            fps = 0
 
                 duration = float(stream["duration"])
-                frames_number = int(stream["nb_frames"]) if "nb_frames" in stream else None
+                # frames_number = int(stream["nb_frames"]) if "nb_frames" in stream else None
+                if "duration_ts" in stream:
+                    frames_number = int(stream["duration_ts"])
+                elif "nb_frames" in stream:
+                    frames_number = int(stream["nb_frames"])
+                else:
+                    frames_number = None
+
                 video_codec = stream["codec_long_name"] if "codec_long_name" in stream else None
 
             if stream["codec_type"] == "audio":
@@ -1244,7 +1342,7 @@ def behavior_color(colors_list: list, idx: int, default_color: str = "darkgray")
     """
 
     try:
-        return colors_list[idx % len(colors_list)]
+        return colors_list[idx % len(colors_list)].replace("tab:", "")
     except Exception:
         return default_color
 
@@ -1266,7 +1364,7 @@ def all_behaviors(ethogram: dict) -> list:
 
 def dir_images_number(dir_path_str: str) -> dict:
     """
-    return number of images in dir_path (*.jpg, *.jpeg, *.png)
+    return number of images in dir_path (see cfg.IMAGE_EXTENSIONS)
     """
 
     dir_path = pl.Path(dir_path_str)
